@@ -205,7 +205,7 @@ def request_obis(eco_code: int = None, aphia_id: int = None) -> pd.DataFrame:
             ),
             axis=1,
         )
-        df_obis = df_obis[df_obis["is_within_polygon"] is True]
+        df_obis = df_obis[df_obis["is_within_polygon"]]
         df_obis = df_obis[["aphiaID", "species", "decimalLatitude", "decimalLongitude"]]
 
     return df_obis.reset_index()
