@@ -97,3 +97,14 @@ def test_ecoregions_plot():
 
     species = ml.Species(145634)
     species.plot()
+
+
+def test_big_region_obis_api():
+    """
+    the obis API calls has issue with big region.
+    It needs special code and this test is to make
+    sure all big regions will run properly.
+    Here we use High Arctic Archipelago (code 25010)
+    """
+    arctic = ml.MarineLife(25010)
+    assert arctic.obis.empty is False
